<?php
/*
Plugin Name: jQuery Comment Preview
Plugin URI: http://dimox.net/jquery-comment-preview-wordpress-plugin/
Description: Live comment preview using jQuery.
Version: 1.1
Author: Dimox
Author URI: http://dimox.net/
*/



function jcp_get_version() {
	return '1.1';
}



function jcp_textdomain() {
	load_plugin_textdomain('jquery-comment-preview', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');
}
add_action('plugins_loaded', 'jcp_textdomain');



function jcp_register_setting() {
	register_setting('jquery_comment_preview', 'jquery_comment_preview', 'jcp_validate');
}
add_action('admin_init', 'jcp_register_setting');



function jcp_plugin_settings_link($links) {
	$settings_link = '<a href="options-general.php?page=jquery-comment-preview.php">' . __('Settings') . '</a>';
	array_unshift($links, $settings_link);
	return $links;
}
$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 'jcp_plugin_settings_link' );



function jcp_uninstall() {
	delete_option('jquery_comment_preview');
}
register_deactivation_hook( __FILE__, 'jcp_uninstall');



function jcp_default_options() {
	$def_options['textarea_name']  = 'comment';
	$def_options['show_text']      = __('Preview', 'jquery-comment-preview');
	$def_options['hide_text']      = __('Hide preview', 'jquery-comment-preview');
	$def_options['preview_html']   = '<div class="comment">'."\n\t".'{avatar}'."\n\t".'<span class="comment-author">{author}</span>'."\n\t".'<span class="comment-date">{date:time}</span>'."\n\t".'{comment}'."\n".'</div>';
	$def_options['avatar_type']    = 1;
	$def_options['avatar_url']     = 'http://www.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=32';
	$def_options['avatar_size']    = '40';
	$def_options['connect_css']    = 1;
	$def_options['connect_js']     = 'top';
	$def_options['syntax_tags']    = '';
	$def_options['show_editor']    = 0;
	$def_options['editor_buttons'] = '<button tag="strong" class="btn-strong">b</button>'."\n".'<button tag="em" class="btn-em">i</button>'."\n".'<button tag="a" class="btn-a">link[href=""]</button>'."\n".'<button tag="blockquote">b-quote</button>'."\n".'<button tag="code">code</button>';
	$def_options['target_blank']   = 1;
	$def_options['smiles']         = 0;
	return $def_options;
}



function jcp_validate($input) {
	$def_options = jcp_default_options();
	$input['textarea_name']  = (!empty($input['textarea_name']) ? $input['textarea_name'] : '');
	$input['show_text']      = (!empty($input['show_text']) ? $input['show_text'] : $def_options['show_text']);
	$input['hide_text']      = (!empty($input['hide_text']) ? $input['hide_text'] : $def_options['hide_text']);
	$input['preview_html']   = (!empty($input['preview_html']) ? $input['preview_html'] : $def_options['preview_html']);
	$input['avatar_type']    = ($input['avatar_type'] == 1 ? 1 : 0);
	$input['avatar_url']     = (!empty($input['avatar_url']) ? $input['avatar_url'] : $def_options['avatar_url']);
	$input['avatar_size']    = (is_numeric($input['avatar_size']) ? $input['avatar_size'] : $def_options['avatar_size']);
	$input['connect_css']    = ($input['connect_css'] == 1 ? 1 : 0);
	$input['connect_js']     = ($input['connect_js'] == 'top' ? 'top' : 'bottom');
	$input['syntax_tags']    = (!empty($input['syntax_tags']) ? $input['syntax_tags'] : '');
	$input['show_editor']    = ($input['show_editor'] == 1 ? 1 : 0);
	$input['editor_buttons'] = (!empty($input['editor_buttons']) ? $input['editor_buttons'] : $def_options['editor_buttons']);
	$input['target_blank']   = ($input['target_blank'] == 1 ? 1 : 0);
	$input['smiles']         = ($input['smiles'] == 1 ? 1 : 0);
	if (isset($_POST['jcp_reset']))     {
		$input = jcp_default_options();
	}
	return $input;
}



function jquery_comment_preview() {

	$options = get_option('jquery_comment_preview');

	$textarea_name  = $options['textarea_name'];
	$show_text      = $options['show_text'];
	$hide_text      = $options['hide_text'];
	$avatar_type    = $options['avatar_type'];
	$avatar_url     = $options['avatar_url'];
	$avatar_size    = $options['avatar_size'];
	$preview_html   = $options['preview_html'];
	$syntax_tags    = $options['syntax_tags'];
	$show_editor    = $options['show_editor'];
	$editor_buttons = $options['editor_buttons'];
	$target_blank   = $options['target_blank'];
	$smiles         = $options['smiles'];

	header('Content-type: text/javascript');
?>
(function($) {
$(function() {

	var container = $('<div class="jcp-container"></div>');
	var textarea = $('textarea[name="<?php echo $textarea_name; ?>"]').before(container).appendTo(container);
	var showText = '<?php $show_text = str_replace('\'', '\\\'', $show_text); echo $show_text; ?>';
	var hideText = '<?php $hide_text = str_replace('\'', '\\\'', $hide_text); echo $hide_text; ?>';
<?php
if ($smiles == '1' && get_option('use_smilies') == '1') {
	$dirRel = 'wp-includes/images/smilies/';
	$dirAbs = get_bloginfo('wpurl') . '/' . $dirRel;
	global $wpsmiliestrans;
	$smiled = array();
	foreach ($wpsmiliestrans as $tag => $smile) {
		if (!in_array($smile, $smiled)) {
			$smiled[$tag] = $smile;
		}
	}
	echo "  var smiles = " . json_encode($smiled) . ";\n";
	echo "  var smilesDir = '" . $dirAbs . "';\n";
}
?>

	var previewTab = $('<a class="jcp-preview-tab">'+ showText +'</a>');
<?php if ($show_editor == 1) { ?>
	var htmlEditor = $('<div class="jcp-html-editor"><?php
		$bracket_left = preg_replace('/(.+)([<[{(])\/button([>\]})])(.+)/s', '$2', $editor_buttons);
		$bracket_right = preg_replace('/(.+)([<[{(])\/button([>\]})])(.+)/s', '$3', $editor_buttons);
		$editor_buttons = preg_replace("/[{$bracket_left}]button (.+)[{$bracket_right}](.+)[{$bracket_left}]\/button[{$bracket_right}]/", "<a $1>$2</a>", $editor_buttons);
		function attribs($matches) {
			return $matches[1] . ' data-attr="' . htmlspecialchars($matches[3]) . '"' . $matches[2] . $matches[4];
		}
		$editor_buttons = preg_replace_callback("/(<a)(.+)\[(.+)\](.+)/", "attribs", $editor_buttons);
		$editor_buttons = str_replace("\r", "", $editor_buttons);
		$editor_buttons = str_replace("\n", "", $editor_buttons);
		$editor_buttons = str_replace("\t", "", $editor_buttons);
		$editor_buttons = str_replace("'", "\"", $editor_buttons);
		$editor_buttons = str_replace(" tag", " data-tag", $editor_buttons);
		echo $editor_buttons ?></div>');
	var toolbar = $('<div class="jcp-toolbar"></div>').insertBefore(textarea).prepend(previewTab).prepend(htmlEditor);
<?php } else { ?>
	var toolbar = $('<div class="jcp-toolbar"></div>').insertBefore(textarea).prepend(previewTab);
<?php } ?>
	var preview = $('<div class="jcp-preview"></div>').hide();
	var bracketLeft = '<?php echo $bracket_left; ?>';
	var bracketRight = '<?php echo $bracket_right; ?>';

	previewTab.click(function() {
		if ( preview.is(':hidden') ) {
			if ( textarea.val() !== '' ) {
				container.addClass('jcp-loading');
<?php if ($show_editor == 1) { ?>
				htmlEditor.hide();
<?php } ?>
				var format = $.post(
					'<?php echo plugins_url('ajax.php', __FILE__) ?>',
					{ content: textarea.val(), tags: '<?php echo $syntax_tags ?>' }
				).done(function(previewText) {
					container.removeClass('jcp-loading');
<?php if (preg_match('/{avatar}/', $preview_html)) { ?>
<?php if ($avatar_type == '1') { ?>
					var email = $('input[name="email"]').val();
					if (!email) email = '<?php global $current_user; echo $current_user->user_email; ?>';
					var md5 = MD5(email);
<?php } ?>
<?php if ($avatar_type == '1') { ?>
					var avatar = '<img src="http://www.gravatar.com/avatar/' + md5 + '?s=<?php echo $avatar_size; ?>" alt="" class="avatar" />';
<?php } else { ?>
					var avatar = '<img src="<?php echo $avatar_url; ?>" alt="" class="avatar" />';
<?php } ?>
<?php } ?>
					var author = $('input[name="author"]').val();
					var url = $('input[name="url"]').val();
					if (!$('input[name="url"]').length) url = '<?php global $current_user; echo $current_user->user_url; ?>';
					if (!$('input[name="author"]').length) author = '<?php global $current_user; echo $current_user->display_name; ?>';
					if (url !== '') author = '<a href="'+ url +'">'+ author +'</a>';
<?php if (preg_match('/{date}/', $preview_html)) { ?>
					var date = '<?php echo date_i18n( get_option('date_format'), false ); ?>';
<?php } elseif (preg_match('/{date:time}/', $preview_html)) { ?>
					var date = '<?php printf(__('%1$s at %2$s'), date_i18n( get_option('date_format'), false ), date_i18n( get_option('time_format'), false )); ?>';
<?php } ?>
					var previewHTML = '<?php
						$preview_html = preg_replace("/<script[^>]*?>.*?<\/script>/si", "", $preview_html);
						$preview_html = str_replace('\'', '\\\'', $preview_html);
						$preview_html = preg_replace("/{avatar}/", "'+ avatar +'", $preview_html);
						$preview_html = preg_replace("/{author}/", "'+ author +'", $preview_html);
						$preview_html = preg_replace("/{date}/", "'+ date +'", $preview_html);
						$preview_html = preg_replace("/{date:time}/", "'+ date +'", $preview_html);
						$preview_html = preg_replace("/{comment}/", "'+ previewText +'", $preview_html);
						$preview_html = str_replace("\r", "", $preview_html);
						$preview_html = str_replace("\n", "", $preview_html);
						$preview_html = str_replace("\t", "", $preview_html);
						echo $preview_html; ?>';
<?php if ($smiles == '1' && get_option('use_smilies') == '1') { ?>
					$.each(smiles, function(key, value) {
						function str_replace(search, replace, subject) {
							var temp = subject.split(search);
							return temp.join(replace);
						}
						previewHTML = str_replace(key, '<img src="' + smilesDir + value + '" />', previewHTML);
					});
<?php } ?>
					previewTab.text(hideText);
					preview.html(previewHTML);
					textarea.hide();
					preview.insertAfter(textarea).show();
					if (typeof jcpPreviewLoaded === 'function') jcpPreviewLoaded();
				});
			}
		} else {
			preview.remove();
<?php if ($show_editor == 1) { ?>
			htmlEditor.show();
<?php } ?>
			previewTab.text(showText);
			textarea.show().focus();
		}
	});

<?php if ($show_editor == 1) { ?>
	function insert(start, end, mid) {
		var midText = '';
		element = textarea[0];
		if (document.selection) {
			element.focus();
			sel = document.selection.createRange();
			if (sel.text === '') midText = mid;
			sel.text = start + sel.text + midText + end;
		} else if (element.selectionStart || element.selectionStart == '0') {
			element.focus();
			var startPos = element.selectionStart;
			var endPos = element.selectionEnd;
			var selText = element.value.substring(startPos, endPos);
			if (selText === '') midText = mid;
			element.value = element.value.substring(0, startPos) + start + selText + midText + end + element.value.substring(endPos, element.value.length);
		} else {
			element.value += start + end;
		}
	}

	htmlEditor.find('a').click(function() {
		var start = '',
				mid = '',
				end = '';
		var tag = $(this).data('tag');
		var attribs = $(this).data('attr');
		if (!attribs) attribs = '';
		if (tag == 'a') {
			var URL = prompt('<?php $url = __('Enter the URL', 'jquery-comment-preview'); $url = str_replace('\'', '\\\'', $url); echo $url; ?>', 'http://');
			if (URL) {
				var blank = '';
<?php if ($target_blank == 1) { ?>
				if (URL.indexOf(window.location.hostname) == -1) blank = ' target="_blank"';
<?php } ?>
				attribs = attribs.replace('href=""', 'href="' + URL + '"' + blank);
<?php if ($target_blank == 1 && preg_match('/_blank/', $editor_buttons)) { ?>
				attribs = attribs.replace(' target="_blank"', '');
<?php } ?>
				start = bracketLeft + tag + ' ' + attribs + bracketRight;
				mid = URL;
				end = bracketLeft + '/' + tag + bracketRight;
			} else {
				start = end = '';
			}
		} else if (tag == 'img') {
			var image = prompt('<?php $image = __('Enter the URL of the image', 'jquery-comment-preview'); echo $image; ?>', 'http://');
			if (image) {
				var imageAlt = prompt('<?php $imageAlt = __('Enter a description of the image', 'jquery-comment-preview'); echo $imageAlt; ?>', '');
				attribs = attribs.replace('src=""', 'src="' + image + '"');
				if (imageAlt) attribs = attribs.replace('alt=""', 'alt="' + imageAlt + '"');
				start = '';
				end = bracketLeft + tag + ' ' + attribs + bracketRight;
			} else {
				start = end = '';
			}
		} else {
			if (attribs !== '') attribs = ' ' + attribs;
			start = bracketLeft + tag + attribs + bracketRight;
			end = bracketLeft + '/' + tag + bracketRight;
		}
		insert(start, end, mid);
	});
<?php if ($smiles == '1' && get_option('use_smilies') == '1') { ?>

	var smilesButton = $('<a class="jcp-smiles"><img src="' + smilesDir + 'icon_smile.gif" alt="" /><span></span></a>').appendTo(htmlEditor);
	$.each(smiles, function(key, value) {
		smilesButton.find('span').append('<img src="' + smilesDir + value + '" alt="' + key + '" />');
	});
	smilesButton.find('img').click(function() {
		insert('', ' ' + $(this).attr('alt') + ' ', '');
	});
<?php } ?>
	htmlEditor.append('<a href="<?php _e('http://dimox.net/jquery-comment-preview-wordpress-plugin/', 'jquery-comment-preview') ?>" target="_blank" title="<?php _e('About the plugin', 'jquery-comment-preview') ?>">?</a>');
<?php } // if ($show_editor == 1) ?>

});<?php echo "\n"; // end $(function() ?>
})(jQuery);
<?php

	die();

}



function jcp_options_page() {
	add_options_page('jQuery Comment Preview', 'jQuery Comment Preview', 'manage_options', 'jquery-comment-preview.php', 'jcp_options');
	if (!get_option("jquery_comment_preview")) {
		$options = jcp_default_options();
		add_option("jquery_comment_preview", $options) ;
	}
}
add_action('admin_menu', 'jcp_options_page');



function jcp_options() {
	$options = get_option('jquery_comment_preview');
	$error = false;
	if ( empty($options['textarea_name']) ) {
		echo '<div id="message" class="error"><p>' . __('Please specify the <code style="background:#FFFBFB">name</code> attribute of the <code style="background:#FFFBFB">textarea</code> tag, else preview will not work.', 'jquery-comment-preview') . '</p></div>';
		$error = ' style="border: 1px solid #C00; background: #FFEBE8;"';
	}
?>

<div class="wrap">

	<h2><?php _e('jQuery Comment Preview Options', 'jquery-comment-preview'); ?></h2>

	<form method="post" action="options.php">
		<?php settings_fields('jquery_comment_preview'); ?>
		<?php $options = get_option('jquery_comment_preview'); ?>

		<div id="poststuff">

			<p><input type="submit" name="jcp_update" class="button-primary" value="<?php _e('Update Options', 'jquery-comment-preview') ?>" /><br /><br /></p>

			<div class="postbox">

				<h3 class="hndle"><?php _e('Preview Options', 'jquery-comment-preview'); ?></h3>

				<div class="inside">

					<table class="form-table">

						<tr>
							<th style="width: 320px"><?php _e('The value of the <code>name</code> attribute of the <code>textarea</code> tag:', 'jquery-comment-preview'); ?></th>
							<td>
								<input<?php echo $error; ?> name="jquery_comment_preview[textarea_name]" type="text" id="textarea_name" value="<?php echo $options['textarea_name']; ?>" size="30" />
								<p class="description"><?php _e('Commonly this value is <code>comment</code>.', 'jquery-comment-preview'); ?></p>
							</td>
						</tr>

						<tr>
							<th><?php _e('"Preview" button text:', 'jquery-comment-preview'); ?></th>
							<td>
								<input name="jquery_comment_preview[show_text]" type="text" id="show_text" value="<?php echo $options['show_text']; ?>" size="30" />
							</td>
						</tr>

						<tr>
							<th><?php _e('"Hide preview" button text:', 'jquery-comment-preview'); ?></th>
							<td>
								<input name="jquery_comment_preview[hide_text]" type="text" id="hide_text" value="<?php echo $options['hide_text']; ?>" size="30" />
							</td>
						</tr>

						<tr>
							<th><?php _e('Preview block template:', 'jquery-comment-preview'); ?></th>
							<td>
								<textarea name="jquery_comment_preview[preview_html]" id="preview_html" cols="85" rows="10" /><?php echo $options['preview_html']; ?></textarea>
								<p class="description">
									<strong><?php _e('Designations:', 'jquery-comment-preview'); ?></strong><br />
									<code>{avatar}</code> - <?php _e('avatar', 'jquery-comment-preview'); ?>;<br />
									<code>{author}</code> - <?php _e('author\'s name with a link', 'jquery-comment-preview'); ?>;<br />
									<code>{date}</code> - <?php _e('comment date', 'jquery-comment-preview'); ?> (<?php _e('will look like', 'jquery-comment-preview'); ?>: <code><?php echo date_i18n( get_option('date_format'), false ); ?></code>);<br />
									<code>{date:time}</code> - <?php _e('comment date and time', 'jquery-comment-preview'); ?> (<?php _e('will look like', 'jquery-comment-preview'); ?>: <code><?php printf(__('%1$s at %2$s'), date_i18n( get_option('date_format'), false ), date_i18n( get_option('time_format'), false )); ?></code>);<br />
									<code>{comment}</code> - <?php _e('comment text', 'jquery-comment-preview'); ?>.<br />
									<?php _e('<strong>The format of the date and time</strong> depends on your', 'jquery-comment-preview'); ?> <a href="<?php echo get_bloginfo('wpurl') ?>/wp-admin/options-general.php"><?php _e('settings', 'jquery-comment-preview'); ?></a>.
								</p>
							</td>
						</tr>

						<tr>
							<th><?php _e('Avatar type:', 'jquery-comment-preview'); ?></th>
							<td style="vertical-align: top">
<script>
(function($) {
$(function() {

	$('input[name="jquery_comment_preview[avatar_type]"').change(function() {
		if ( $(this).val() == 1 ) {
			$('.hide').addClass('hide_this');
			$('.show').removeClass('hide_this');
		} else {
			$('.hide').removeClass('hide_this');
			$('.show').addClass('hide_this');
		}
	});

});
})(jQuery);
</script>
<style>
.hide_this {display: none}
</style>
								<label for="dynamic"><input type="radio" name="jquery_comment_preview[avatar_type]" id="dynamic" value="1" <?php checked($options['avatar_type'], 1); ?> /> <?php _e('Dynamic', 'jquery-comment-preview'); ?></label>
								&nbsp;&nbsp;&nbsp;
								<label for="static"><input type="radio" name="jquery_comment_preview[avatar_type]" id="static" value="0" <?php checked($options['avatar_type'], 0); ?> /> <?php _e('Static', 'jquery-comment-preview'); ?></label>

								<div class="show<?php if ($options['avatar_type'] == 0) echo ' hide_this'; ?>"><p class="description"><?php _e('Avatar will vary depending on an e-mail address of commentator. Used <a href="http://gravatar.com/" target="_blank">Gravatar</a> service.', 'jquery-comment-preview'); ?></p></div>
							</td>
						</tr>

						<tr class="hide<?php if ($options['avatar_type'] == 1) echo ' hide_this'; ?>">
							<th><?php _e('Link on static avatar:', 'jquery-comment-preview'); ?></th>
							<td>
								<input name="jquery_comment_preview[avatar_url]" id="avatar_url" type="text" value="<?php $avatar_url = preg_replace('/=(\d+)/', '='.$options['avatar_size'], $options['avatar_url']); echo $avatar_url; ?>" size="85" />
								<p class="description"><?php _e('Avatar will <strong>not</strong> vary depending on an e-mail address of commentator.', 'jquery-comment-preview'); ?></p>
							</td>
						</tr>

						<tr>
							<th><?php _e('Avatar size:', 'jquery-comment-preview'); ?></th>
							<td>
<script>
(function($) {
$(function() {

	$('#avatar_size_1').keyup(function() {
		$('#avatar_size_2').val($('#avatar_size_1').val());
	})

});
})(jQuery);
</script>
								<input name="jquery_comment_preview[avatar_size]" id="avatar_size_1" type="text" value="<?php echo $options['avatar_size']; ?>" size="2" maxlength="3" style="width:33px" /> x <input name="" id="avatar_size_2" type="text" value="<?php echo $options['avatar_size']; ?>" size="2" maxlength="3" disabled="disabled" style="width:33px" /> px
							</td>
						</tr>

						<tr>
							<th><?php _e('Connect a plugin\'s CSS file?', 'jquery-comment-preview'); ?></th>
							<td>
								<label for="connect_css_yes"><input type="radio" name="jquery_comment_preview[connect_css]" id="connect_css_yes" value="1" <?php checked($options['connect_css'], 1); ?> /> <?php _e('Yes', 'jquery-comment-preview'); ?></label>
								&nbsp;&nbsp;&nbsp;
								<label for="connect_css_no"><input type="radio" name="jquery_comment_preview[connect_css]" id="connect_css_no" value="0" <?php checked($options['connect_css'], 0); ?> /> <?php _e('No', 'jquery-comment-preview'); ?></label>

								<p class="description">
									<?php _e('If you wish to reduce a number of queries to the server it can be useful not to connect an additional CSS file applied to the plugin. In that case choose "No". Thus it is necessary to insert a styles from the <code>jquery-comment-preview.css</code> file into a CSS file of your theme (<code>style.css</code>).', 'jquery-comment-preview'); ?>
										<br /><br />
										<?php _e('The CSS file is located on the following path', 'jquery-comment-preview'); ?>: <br /><code><?php echo plugins_url( 'jquery-comment-preview.css', __FILE__ ); ?></code>
								</p>
							</td>
						</tr>

						<tr>
							<th><?php _e('Where to connect the plugin\'s JS files:', 'jquery-comment-preview'); ?></th>
							<td>
								<label for="connect_js_top"><input type="radio" name="jquery_comment_preview[connect_js]" id="connect_js_top" value="top" <?php checked($options['connect_js'], 'top'); ?> /> <?php _e('Before the <code>&lt;/head></code> tag', 'jquery-comment-preview'); ?></label>
								&nbsp;&nbsp;&nbsp;
								<label for="connect_js_bottom"><input type="radio" name="jquery_comment_preview[connect_js]" id="connect_js_bottom" value="bottom" <?php checked($options['connect_js'], 'bottom'); ?> /> <?php _e('Before the <code>&lt;/body></code> tag', 'jquery-comment-preview'); ?></label>
							</td>
						</tr>

						<tr>
							<th><?php _e('Tags used for syntax highlighting:', 'jquery-comment-preview'); ?></th>
							<td>
							<input name="jquery_comment_preview[syntax_tags]" type="text" id="syntax_tags" value="<?php echo $options['syntax_tags']; ?>" size="30" />
								<p class="description"><?php _e('If you are using a third-party plugin for syntax highlighting, specify tag names (<strong>separated by commas and without brackets</strong>), within which there is highlighted code. This is necessary for converting <code><</code> and <code>></code> into <code>&amp;lt;</code> and <code>&amp;gt;</code> inside these tags.<br /> Example: <code>code,pre</code>', 'jquery-comment-preview'); ?></p>
							</td>
						</tr>

					</table>

				</div><!-- .inside -->

			</div><!-- .postbox -->

			<div class="postbox">

			<h3 class="hndle"><?php _e('HTML Editor Options', 'jquery-comment-preview'); ?></h3>

				<div class="inside">

					<table class="form-table">

						<tr>
							<th colspan="2"><strong style="color: #F60"><?php _e('The HTML editor allows to quickly insert a HTML tags into a comment text.', 'jquery-comment-preview'); ?></strong></th>
						</tr>

						<tr>
							<th style="width: 320px"><?php _e('Show the HTML editor?', 'jquery-comment-preview'); ?></th>
							<td>
<script>
(function($) {
$(function() {

	$('input[name="jquery_comment_preview[show_editor]"').change(function() {
		if ( $(this).val() == 0 ) {
			$('.hide2').addClass('hide_this');
		} else {
			$('.hide2').removeClass('hide_this');
		}
	});

});
})(jQuery);
</script>
								<label for="show_editor_yes"><input type="radio" name="jquery_comment_preview[show_editor]" id="show_editor_yes" value="1" <?php checked($options['show_editor'], 1); ?> /> <?php _e('Yes', 'jquery-comment-preview'); ?></label>
								&nbsp;&nbsp;&nbsp;
								<label for="show_editor_no"><input type="radio" name="jquery_comment_preview[show_editor]" id="show_editor_no" value="0" <?php checked($options['show_editor'], 0); ?> /> <?php _e('No', 'jquery-comment-preview'); ?></label>
							</td>
						</tr>

						<tr class="hide2<?php if ($options['show_editor'] == 0) echo ' hide_this'; ?>">
							<th><?php _e('HTML code of a buttons of the editor:', 'jquery-comment-preview'); ?></th>
							<td>
								<textarea name="jquery_comment_preview[editor_buttons]" id="editor_buttons" cols="85" rows="10" /><?php echo $options['editor_buttons']; ?></textarea><br />
								<p class="description">
									<strong><?php _e('Explanations:', 'jquery-comment-preview'); ?></strong>
									<br />
									<ol>
										<li><p class="description"><?php _e('A button <strong>necessarily</strong> should always have a <code>tag</code> parameter and a tag name as value. For example, If you create a button for the <code>&lt;code>&lt;/code></code> tag, this parameter should be looks like this: <code>&lt;button <strong>tag="code"</strong>>...&lt;button></code>.', 'jquery-comment-preview'); ?></p></li>
										<li><p class="description"><?php _e('Between the tags <code><strong>&lt;button></strong></code> and <code><strong>&lt;/button></strong></code> it is necessary to specify a <strong>name of a button</strong>.', 'jquery-comment-preview'); ?></p></li>
										<li><p class="description"><?php _e('If you wish to <strong>add a parameters to a tag</strong>, it is necessary to set them in square brackets after a button name. For example, to receive a button for the <code>&lt;a href="">&lt;/a></code> tag, it is necessary to write the following code: <code>&lt;button <strong>tag="a"</strong>>link<strong>[href=""]</strong>&lt;/button></code>.', 'jquery-comment-preview'); ?></p></li>
									</ol>
								</p>
							</td>
						</tr>

						<tr class="hide2<?php if ($options['show_editor'] == 0) echo ' hide_this'; ?>">
							<th><?php _e('Add the <code>target="_blank"</code> parameter to external links?', 'jquery-comment-preview'); ?></th>
							<td>
								<label for="target_blank_yes"><input type="radio" name="jquery_comment_preview[target_blank]" id="target_blank_yes" value="1" <?php checked($options['target_blank'], 1); ?> /> <?php _e('Yes', 'jquery-comment-preview'); ?></label>
								&nbsp;&nbsp;&nbsp;
								<label for="target_blank_no"><input type="radio" name="jquery_comment_preview[target_blank]" id="target_blank_no" value="0" <?php checked($options['target_blank'], 0); ?> /> <?php _e('No', 'jquery-comment-preview'); ?></label>

								<p class="description"><?php _e('This option is used for the button adds a link.', 'jquery-comment-preview'); ?></p>
							</td>
						</tr>

						<tr class="hide2<?php if ($options['show_editor'] == 0) echo ' hide_this'; ?>">
							<th><?php _e('Show button with WordPress smilies?', 'jquery-comment-preview'); ?></th>
							<td>
								<label for="smiles_yes"><input type="radio" name="jquery_comment_preview[smiles]" id="smiles_yes" value="1" <?php checked($options['smiles'], 1); ?> /> <?php _e('Yes', 'jquery-comment-preview'); ?></label>
								&nbsp;&nbsp;&nbsp;
								<label for="smiles_no"><input type="radio" name="jquery_comment_preview[smiles]" id="smiles_no" value="0" <?php checked($options['smiles'], 0); ?> /> <?php _e('No', 'jquery-comment-preview'); ?></label>

								<p class="description"><?php _e('To make this feature work, the following option should be activated on ', 'jquery-comment-preview'); ?> <a href="<?php echo get_bloginfo('wpurl') ?>/wp-admin/options-writing.php"><?php _e('this page', 'jquery-comment-preview'); ?></a>:<br /> <code><?php _e('Convert emoticons like <code>:-)</code> and <code>:-P</code> to graphics on display') ?></code>.</p>
							</td>
						</tr>

					</table>

				</div><!-- .inside -->

			</div><!-- .postbox -->

			<p><input type="submit" name="jcp_update" class="button-primary" value="<?php _e('Update Options', 'jquery-comment-preview') ?>" /></p>

			<br /><br /><br /><br />

			<p><input type="submit" name="jcp_reset" class="button-primary" value=" <?php _e('Reset Defaults', 'jquery-comment-preview') ?> " /><br /><br /></p>

			<div class="postbox">

			<h3 class="hndle"><?php _e('Copyright', 'article-directory'); ?></h3>

				<div class="inside">

					<p>&copy; 2008-<?php echo date('Y'); ?> <a href="<?php _e('http://dimox.net', 'jquery-comment-preview') ?>">Dimox</a> | <a href="<?php _e('http://dimox.net/jquery-comment-preview-wordpress-plugin/', 'jquery-comment-preview') ?>">jQuery Comment Preview</a> | <?php _e('version', 'jquery-comment-preview') ?> <?php echo jcp_get_version() ?></p>

				</div><!-- .inside -->

			</div><!-- .postbox -->

		</div><!-- #poststuff -->

	</form>

</div><!-- .wrap -->

<?php

}



$options = get_option('jquery_comment_preview');



// Подключаем CSS-файл
function jcp_css() {
	global $options;
	if ( comments_open() && is_singular() && $options['connect_css'] == 1 ) {
		wp_register_style('jcp_css', plugins_url('jquery-comment-preview.css', __FILE__), false, jcp_get_version());
		wp_enqueue_style('jcp_css');
	}
}
add_action('wp_print_styles', 'jcp_css');



// Подключаем JS-файлы
function jcp_js() {
	global $options;
	$bottom = false;
	if ($options['connect_js'] == 'bottom') $bottom = true;
	if ( comments_open() && is_singular() ) {
		wp_deregister_script('jquery');
		wp_enqueue_script('jquery-core', get_bloginfo('wpurl') . '/wp-includes/js/jquery/jquery.js', false, null, $bottom);
		wp_enqueue_script('jcp_js', get_bloginfo('wpurl') . '/?s=jquery-comment-preview.js?' . time(), false, null, $bottom);
		if ( $options['avatar_type'] == '1' && preg_match('/{avatar}/', $options['preview_html']) ) {
			wp_enqueue_script('jcp_js_md5', plugins_url('md5.js', __FILE__), false, null, $bottom);
		}
	}
}
add_action('wp_enqueue_scripts', 'jcp_js');



if ( stristr($_SERVER['REQUEST_URI'], 'jquery-comment-preview.js') ) {
	add_action('template_redirect', 'jquery_comment_preview');
}


?>